**To stop a running query**

The following ``stop-query-execution`` example stops the query that has the specified query ID. ::

    aws athena stop-query-execution \
        --query-execution-id a1b2c3d4-5678-90ab-cdef-EXAMPLE11111

This command produces no output.

For more information, see `Running SQL Queries Using Amazon Athena <https://docs.aws.amazon.com/athena/latest/ug/querying-athena-tables.html>`__ in the *Amazon Athena User Guide*.